# reallife : 项目级别
我们开始做一个升级, 0.2 为稳定本地版, 0.3 要做成client 和server 的配合, 新拉一个分支来做
快捷调度生活,将快捷指令系统构成的真实人生系统编写为以代码为主的模式, 为真实人生项目提供标准化工具

python -m src.reallife.server


cd src;python -m reallife.server 8120 #test